# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuditLogDomain(str, Enum):
    """
    AuditLogDomain
    """

    """
    allowed enum values
    """
    NTC_MANAGEMENT = 'NTC_MANAGEMENT'
    ATC_MANAGEMENT = 'ATC_MANAGEMENT'
    UNPLANNED_OUTAGES = 'UNPLANNED_OUTAGES'
    PLANNED_OUTAGES = 'PLANNED_OUTAGES'
    NOMINATIONS = 'NOMINATIONS'
    DEFAULT_NOMINATIONS = 'DEFAULT_NOMINATIONS'
    NOMINATION_CANCELLATION = 'NOMINATION_CANCELLATION'
    CRISIS_MANAGEMENT = 'CRISIS_MANAGEMENT'
    ATTACHMENTS = 'ATTACHMENTS'
    ORGANISATIONS = 'ORGANISATIONS'
    USERS = 'USERS'
    PROFILE = 'PROFILE'
    PARTICIPANT_DASHBOARD = 'PARTICIPANT_DASHBOARD'
    BPP = 'BPP'
    MANUAL_FILE_UPLOAD = 'MANUAL_FILE_UPLOAD'
    BUSINESS_SETTINGS = 'BUSINESS_SETTINGS'
    BUSINESS_PROCESSES = 'BUSINESS_PROCESSES'
    DATA_FLOWS = 'DATA_FLOWS'

    @classmethod
    def from_json(cls, json_str: str) -> AuditLogDomain:
        """Create an instance of AuditLogDomain from a JSON string"""
        return AuditLogDomain(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class DefaultNominationSortBy(str, Enum):
    """
    DefaultNominationSortBy
    """

    """
    allowed enum values
    """
    TIMESCALE_ASC = 'TIMESCALE_ASC'
    TIMESCALE_DESC = 'TIMESCALE_DESC'
    DELIVERY_PERIOD_START_ASC = 'DELIVERY_PERIOD_START_ASC'
    DELIVERY_PERIOD_START_DESC = 'DELIVERY_PERIOD_START_DESC'
    DELIVERY_PERIOD_END_ASC = 'DELIVERY_PERIOD_END_ASC'
    DELIVERY_PERIOD_END_DESC = 'DELIVERY_PERIOD_END_DESC'
    BORDER_DIRECTION_ASC = 'BORDER_DIRECTION_ASC'
    BORDER_DIRECTION_DESC = 'BORDER_DIRECTION_DESC'

    @classmethod
    def from_json(cls, json_str: str) -> DefaultNominationSortBy:
        """Create an instance of DefaultNominationSortBy from a JSON string"""
        return DefaultNominationSortBy(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date

from pydantic import BaseModel, Field
from helix_platform_api_public_client.models.nomination_gate_status import NominationGateStatus
from helix_platform_api_public_client.models.timescale_long_term_or_day_ahead import TimescaleLongTermOrDayAhead

class LongTermOrDayAheadNominationGate(BaseModel):
    """
    LongTermOrDayAheadNominationGate
    """
    delivery_day: date = Field(..., alias="deliveryDay", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    timescale: TimescaleLongTermOrDayAhead = Field(...)
    status: NominationGateStatus = Field(...)
    __properties = ["deliveryDay", "timescale", "status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LongTermOrDayAheadNominationGate:
        """Create an instance of LongTermOrDayAheadNominationGate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LongTermOrDayAheadNominationGate:
        """Create an instance of LongTermOrDayAheadNominationGate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LongTermOrDayAheadNominationGate.parse_obj(obj)

        _obj = LongTermOrDayAheadNominationGate.parse_obj({
            "delivery_day": obj.get("deliveryDay"),
            "timescale": obj.get("timescale"),
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from datetime import datetime

from pydantic import Field, StrictStr, conint, conlist

from typing import Optional

from helix_platform_api_public_client.models.audit_log_batch import AuditLogBatch
from helix_platform_api_public_client.models.audit_log_domain import AuditLogDomain
from helix_platform_api_public_client.models.audit_log_payload import AuditLogPayload
from helix_platform_api_public_client.models.audit_log_sort_by import AuditLogSortBy
from helix_platform_api_public_client.models.audit_log_status import AuditLogStatus

from helix_platform_api_public_client.api_client import ApiClient
from helix_platform_api_public_client.api_response import ApiResponse
from helix_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AuditLogApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_audit_log_payload(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> AuditLogPayload:  # noqa: E501
        """get_audit_log_payload  # noqa: E501

        Fetch payload for an existing Audit Log entry by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AUDIT_LOGS`   * `VIEW_ANY_AUDIT_LOGS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_audit_log_payload(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuditLogPayload
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_audit_log_payload_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_audit_log_payload_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_audit_log_payload_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_audit_log_payload  # noqa: E501

        Fetch payload for an existing Audit Log entry by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AUDIT_LOGS`   * `VIEW_ANY_AUDIT_LOGS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_audit_log_payload_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuditLogPayload, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_log_payload" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "AuditLogPayload",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/audit-logs/{id}/payload', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_audit_logs(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], sort_by : AuditLogSortBy, offset : Annotated[Optional[conint(strict=True, ge=0)], Field(description="Offset in the list of records to return")] = None, id_offset : Annotated[Optional[StrictStr], Field(description="Offset by ID in the list of records to return")] = None, domains : Optional[conlist(AuditLogDomain)] = None, x_organisation_id : Annotated[Optional[StrictStr], Field(description="Internal ID of an Organisation (optional)")] = None, creation_period_start : Optional[datetime] = None, creation_period_end : Optional[datetime] = None, query : Optional[StrictStr] = None, status : Optional[conlist(AuditLogStatus)] = None, **kwargs) -> AuditLogBatch:  # noqa: E501
        """get_audit_logs  # noqa: E501

        Fetch a list of Audit Logs optionally filtered for an Organisation  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AUDIT_LOGS`   * `VIEW_ANY_AUDIT_LOGS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_audit_logs(limit, sort_by, offset, id_offset, domains, x_organisation_id, creation_period_start, creation_period_end, query, status, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param sort_by: (required)
        :type sort_by: AuditLogSortBy
        :param offset: Offset in the list of records to return
        :type offset: int
        :param id_offset: Offset by ID in the list of records to return
        :type id_offset: str
        :param domains:
        :type domains: List[AuditLogDomain]
        :param x_organisation_id: Internal ID of an Organisation (optional)
        :type x_organisation_id: str
        :param creation_period_start:
        :type creation_period_start: datetime
        :param creation_period_end:
        :type creation_period_end: datetime
        :param query:
        :type query: str
        :param status:
        :type status: List[AuditLogStatus]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuditLogBatch
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_audit_logs_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_audit_logs_with_http_info(limit, sort_by, offset, id_offset, domains, x_organisation_id, creation_period_start, creation_period_end, query, status, **kwargs)  # noqa: E501

    @validate_arguments
    def get_audit_logs_with_http_info(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], sort_by : AuditLogSortBy, offset : Annotated[Optional[conint(strict=True, ge=0)], Field(description="Offset in the list of records to return")] = None, id_offset : Annotated[Optional[StrictStr], Field(description="Offset by ID in the list of records to return")] = None, domains : Optional[conlist(AuditLogDomain)] = None, x_organisation_id : Annotated[Optional[StrictStr], Field(description="Internal ID of an Organisation (optional)")] = None, creation_period_start : Optional[datetime] = None, creation_period_end : Optional[datetime] = None, query : Optional[StrictStr] = None, status : Optional[conlist(AuditLogStatus)] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """get_audit_logs  # noqa: E501

        Fetch a list of Audit Logs optionally filtered for an Organisation  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AUDIT_LOGS`   * `VIEW_ANY_AUDIT_LOGS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_audit_logs_with_http_info(limit, sort_by, offset, id_offset, domains, x_organisation_id, creation_period_start, creation_period_end, query, status, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param sort_by: (required)
        :type sort_by: AuditLogSortBy
        :param offset: Offset in the list of records to return
        :type offset: int
        :param id_offset: Offset by ID in the list of records to return
        :type id_offset: str
        :param domains:
        :type domains: List[AuditLogDomain]
        :param x_organisation_id: Internal ID of an Organisation (optional)
        :type x_organisation_id: str
        :param creation_period_start:
        :type creation_period_start: datetime
        :param creation_period_end:
        :type creation_period_end: datetime
        :param query:
        :type query: str
        :param status:
        :type status: List[AuditLogStatus]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuditLogBatch, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'sort_by',
            'offset',
            'id_offset',
            'domains',
            'x_organisation_id',
            'creation_period_start',
            'creation_period_end',
            'query',
            'status'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_logs" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('id_offset') is not None:  # noqa: E501
            _query_params.append(('idOffset', _params['id_offset']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sortBy', _params['sort_by'].value))

        if _params.get('domains') is not None:  # noqa: E501
            _query_params.append(('domains', _params['domains']))
            _collection_formats['domains'] = 'multi'

        if _params.get('creation_period_start') is not None:  # noqa: E501
            if isinstance(_params['creation_period_start'], datetime):
                _query_params.append(('creationPeriodStart', _params['creation_period_start'].isoformat()))
            else:
                _query_params.append(('creationPeriodStart', _params['creation_period_start']))

        if _params.get('creation_period_end') is not None:  # noqa: E501
            if isinstance(_params['creation_period_end'], datetime):
                _query_params.append(('creationPeriodEnd', _params['creation_period_end'].isoformat()))
            else:
                _query_params.append(('creationPeriodEnd', _params['creation_period_end']))

        if _params.get('query') is not None:  # noqa: E501
            _query_params.append(('query', _params['query']))

        if _params.get('status') is not None:  # noqa: E501
            _query_params.append(('status', _params['status']))
            _collection_formats['status'] = 'multi'

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_organisation_id']:
            _header_params['X-Organisation-Id'] = _params['x_organisation_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "AuditLogBatch",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/audit-logs', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuditLogType(str, Enum):
    """
    AuditLogType
    """

    """
    allowed enum values
    """
    SUBMIT_NTC = 'SUBMIT_NTC'
    SUBMIT_ATC = 'SUBMIT_ATC'
    CREATE_UNPLANNED_OUTAGE = 'CREATE_UNPLANNED_OUTAGE'
    UPDATE_UNPLANNED_OUTAGE = 'UPDATE_UNPLANNED_OUTAGE'
    CANCEL_UNPLANNED_OUTAGE = 'CANCEL_UNPLANNED_OUTAGE'
    END_UNPLANNED_OUTAGE = 'END_UNPLANNED_OUTAGE'
    CREATE_PLANNED_OUTAGE = 'CREATE_PLANNED_OUTAGE'
    UPDATE_PLANNED_OUTAGE = 'UPDATE_PLANNED_OUTAGE'
    DELETE_PLANNED_OUTAGE = 'DELETE_PLANNED_OUTAGE'
    CANCEL_PLANNED_OUTAGE = 'CANCEL_PLANNED_OUTAGE'
    SUBMIT_NOMINATIONS = 'SUBMIT_NOMINATIONS'
    CREATE_DEFAULT_NOMINATION = 'CREATE_DEFAULT_NOMINATION'
    UPDATE_DEFAULT_NOMINATION = 'UPDATE_DEFAULT_NOMINATION'
    DELETE_DEFAULT_NOMINATION = 'DELETE_DEFAULT_NOMINATION'
    CANCEL_LONG_TERM_OR_DAY_AHEAD_NOMINATION_GATE = 'CANCEL_LONG_TERM_OR_DAY_AHEAD_NOMINATION_GATE'
    CANCEL_INTRA_DAY_NOMINATION_GATES = 'CANCEL_INTRA_DAY_NOMINATION_GATES'
    RESEND_CRISIS_REMIT = 'RESEND_CRISIS_REMIT'
    BYPASS_CRISIS_REMIT = 'BYPASS_CRISIS_REMIT'
    COMPLETE_CRISIS_STATIC_TASK = 'COMPLETE_CRISIS_STATIC_TASK'
    EXECUTE_CRISIS_CURTAILMENT = 'EXECUTE_CRISIS_CURTAILMENT'
    DISMISS_CRISIS_BPP = 'DISMISS_CRISIS_BPP'
    POST_CRISIS_PARTICIPANT_MESSAGE = 'POST_CRISIS_PARTICIPANT_MESSAGE'
    UPLOAD_ATTACHMENT = 'UPLOAD_ATTACHMENT'
    CREATE_PARTICIPANT_ORGANISATION = 'CREATE_PARTICIPANT_ORGANISATION'
    UPDATE_PARTICIPANT_ORGANISATION = 'UPDATE_PARTICIPANT_ORGANISATION'
    UPDATE_USER = 'UPDATE_USER'
    INVITE_USER = 'INVITE_USER'
    BULK_INVITE_USERS = 'BULK_INVITE_USERS'
    RESEND_USER_INVITE = 'RESEND_USER_INVITE'
    REVOKE_USER_INVITE = 'REVOKE_USER_INVITE'
    SUSPEND_USER = 'SUSPEND_USER'
    UNSUSPEND_USER = 'UNSUSPEND_USER'
    RESET_USER_SECOND_AUTH_FACTOR = 'RESET_USER_SECOND_AUTH_FACTOR'
    IMPERSONATE_USER = 'IMPERSONATE_USER'
    UPDATE_PROFILE_DETAILS = 'UPDATE_PROFILE_DETAILS'
    UPDATE_PREFERENCES = 'UPDATE_PREFERENCES'
    CREATE_API_KEY = 'CREATE_API_KEY'
    DELETE_API_KEY = 'DELETE_API_KEY'
    SUBMIT_PARTICIPANT_DASHBOARD_NOMINATIONS = 'SUBMIT_PARTICIPANT_DASHBOARD_NOMINATIONS'
    SUBMIT_BPP_PURCHASE_FORM = 'SUBMIT_BPP_PURCHASE_FORM'
    SET_BPP_SUBMISSION_STATUS = 'SET_BPP_SUBMISSION_STATUS'
    RESUBMIT_BPP_SUBMISSION = 'RESUBMIT_BPP_SUBMISSION'
    UPLOAD_NOMINATIONS = 'UPLOAD_NOMINATIONS'
    UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOWS_BUSINESS_SETTINGS = 'UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOWS_BUSINESS_SETTINGS'
    UPDATE_INTRA_DAY_NOMINATION_WINDOWS_BUSINESS_SETTINGS = 'UPDATE_INTRA_DAY_NOMINATION_WINDOWS_BUSINESS_SETTINGS'
    UPDATE_BPP_PROVIDER_BUSINESS_SETTINGS = 'UPDATE_BPP_PROVIDER_BUSINESS_SETTINGS'
    MANUAL_START_BUSINESS_PROCESS_WORKFLOW = 'MANUAL_START_BUSINESS_PROCESS_WORKFLOW'
    RESCHEDULE_BUSINESS_PROCESS_WORKFLOW = 'RESCHEDULE_BUSINESS_PROCESS_WORKFLOW'
    SKIP_BUSINESS_PROCESS_WORKFLOW = 'SKIP_BUSINESS_PROCESS_WORKFLOW'
    RESOLVE_BUSINESS_PROCESS_STEP = 'RESOLVE_BUSINESS_PROCESS_STEP'
    RE_RUN_BUSINESS_PROCESS_STEP = 'RE_RUN_BUSINESS_PROCESS_STEP'
    PROCESS_DATA_FLOW_VERSION = 'PROCESS_DATA_FLOW_VERSION'
    CREATE_DATA_FLOW = 'CREATE_DATA_FLOW'
    UPDATE_DATA_FLOW = 'UPDATE_DATA_FLOW'

    @classmethod
    def from_json(cls, json_str: str) -> AuditLogType:
        """Create an instance of AuditLogType from a JSON string"""
        return AuditLogType(json.loads(json_str))





# flake8: noqa

# import apis into api package
from helix_platform_api_public_client.api.attachment_api import AttachmentApi
from helix_platform_api_public_client.api.audit_log_api import AuditLogApi
from helix_platform_api_public_client.api.default_nomination_api import DefaultNominationApi
from helix_platform_api_public_client.api.manual_file_upload_api import ManualFileUploadApi
from helix_platform_api_public_client.api.messages_api import MessagesApi
from helix_platform_api_public_client.api.metadata_api import MetadataApi
from helix_platform_api_public_client.api.nomination_api import NominationApi
from helix_platform_api_public_client.api.nomination_gate_api import NominationGateApi
from helix_platform_api_public_client.api.organisation_api import OrganisationApi
from helix_platform_api_public_client.api.participant_dashboard_api import ParticipantDashboardApi
from helix_platform_api_public_client.api.participant_overview_api import ParticipantOverviewApi
from helix_platform_api_public_client.api.profile_api import ProfileApi
from helix_platform_api_public_client.api.public_overview_api import PublicOverviewApi
from helix_platform_api_public_client.api.reporting_api import ReportingApi
from helix_platform_api_public_client.api.transmission_right_api import TransmissionRightApi
from helix_platform_api_public_client.api.user_api import UserApi




# coding: utf-8

# flake8: noqa

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.117"

# import apis into sdk package
from helix_platform_api_public_client.api.attachment_api import AttachmentApi
from helix_platform_api_public_client.api.audit_log_api import AuditLogApi
from helix_platform_api_public_client.api.default_nomination_api import DefaultNominationApi
from helix_platform_api_public_client.api.manual_file_upload_api import ManualFileUploadApi
from helix_platform_api_public_client.api.messages_api import MessagesApi
from helix_platform_api_public_client.api.metadata_api import MetadataApi
from helix_platform_api_public_client.api.nomination_api import NominationApi
from helix_platform_api_public_client.api.nomination_gate_api import NominationGateApi
from helix_platform_api_public_client.api.organisation_api import OrganisationApi
from helix_platform_api_public_client.api.participant_dashboard_api import ParticipantDashboardApi
from helix_platform_api_public_client.api.participant_overview_api import ParticipantOverviewApi
from helix_platform_api_public_client.api.profile_api import ProfileApi
from helix_platform_api_public_client.api.public_overview_api import PublicOverviewApi
from helix_platform_api_public_client.api.reporting_api import ReportingApi
from helix_platform_api_public_client.api.transmission_right_api import TransmissionRightApi
from helix_platform_api_public_client.api.user_api import UserApi

# import ApiClient
from helix_platform_api_public_client.api_response import ApiResponse
from helix_platform_api_public_client.api_client import ApiClient
from helix_platform_api_public_client.configuration import Configuration
from helix_platform_api_public_client.exceptions import OpenApiException
from helix_platform_api_public_client.exceptions import ApiTypeError
from helix_platform_api_public_client.exceptions import ApiValueError
from helix_platform_api_public_client.exceptions import ApiKeyError
from helix_platform_api_public_client.exceptions import ApiAttributeError
from helix_platform_api_public_client.exceptions import ApiException

# import models into sdk package
from helix_platform_api_public_client.models.aggregated_nomination_options import AggregatedNominationOptions
from helix_platform_api_public_client.models.aggregated_nomination_options_nominee_participants import AggregatedNominationOptionsNomineeParticipants
from helix_platform_api_public_client.models.aggregated_nominations import AggregatedNominations
from helix_platform_api_public_client.models.aggregated_nominations_values import AggregatedNominationsValues
from helix_platform_api_public_client.models.aggregated_nominations_values_mtus import AggregatedNominationsValuesMtus
from helix_platform_api_public_client.models.aggregated_nominations_values_mtus_netted_nominations import AggregatedNominationsValuesMtusNettedNominations
from helix_platform_api_public_client.models.aggregated_nominations_values_mtus_values import AggregatedNominationsValuesMtusValues
from helix_platform_api_public_client.models.aggregated_pre_nomination_options import AggregatedPreNominationOptions
from helix_platform_api_public_client.models.aggregated_pre_nomination_options_timescale import AggregatedPreNominationOptionsTimescale
from helix_platform_api_public_client.models.api_key import ApiKey
from helix_platform_api_public_client.models.attachment import Attachment
from helix_platform_api_public_client.models.audit_log import AuditLog
from helix_platform_api_public_client.models.audit_log_api_key import AuditLogApiKey
from helix_platform_api_public_client.models.audit_log_batch import AuditLogBatch
from helix_platform_api_public_client.models.audit_log_domain import AuditLogDomain
from helix_platform_api_public_client.models.audit_log_payload import AuditLogPayload
from helix_platform_api_public_client.models.audit_log_sort_by import AuditLogSortBy
from helix_platform_api_public_client.models.audit_log_status import AuditLogStatus
from helix_platform_api_public_client.models.audit_log_type import AuditLogType
from helix_platform_api_public_client.models.audit_log_user import AuditLogUser
from helix_platform_api_public_client.models.audit_log_user_organisation import AuditLogUserOrganisation
from helix_platform_api_public_client.models.border_direction import BorderDirection
from helix_platform_api_public_client.models.border_direction_with_both import BorderDirectionWithBoth
from helix_platform_api_public_client.models.border_direction_with_both_and_none import BorderDirectionWithBothAndNone
from helix_platform_api_public_client.models.bulk_invite_organisation_users_request import BulkInviteOrganisationUsersRequest
from helix_platform_api_public_client.models.bulk_invited_organisation_users import BulkInvitedOrganisationUsers
from helix_platform_api_public_client.models.business_process_content_block import BusinessProcessContentBlock
from helix_platform_api_public_client.models.business_process_fork_block import BusinessProcessForkBlock
from helix_platform_api_public_client.models.business_process_step_attempt import BusinessProcessStepAttempt
from helix_platform_api_public_client.models.business_process_step_block import BusinessProcessStepBlock
from helix_platform_api_public_client.models.business_process_step_logic_type import BusinessProcessStepLogicType
from helix_platform_api_public_client.models.business_process_step_status import BusinessProcessStepStatus
from helix_platform_api_public_client.models.business_process_step_type import BusinessProcessStepType
from helix_platform_api_public_client.models.create_api_key_request import CreateApiKeyRequest
from helix_platform_api_public_client.models.create_default_nomination_request import CreateDefaultNominationRequest
from helix_platform_api_public_client.models.created_api_key import CreatedApiKey
from helix_platform_api_public_client.models.created_default_nomination import CreatedDefaultNomination
from helix_platform_api_public_client.models.dashboard_next_nomination_gate import DashboardNextNominationGate
from helix_platform_api_public_client.models.dashboard_next_nomination_gate_window import DashboardNextNominationGateWindow
from helix_platform_api_public_client.models.dashboard_next_nomination_window_status import DashboardNextNominationWindowStatus
from helix_platform_api_public_client.models.data_flow_direction import DataFlowDirection
from helix_platform_api_public_client.models.default_nomination import DefaultNomination
from helix_platform_api_public_client.models.default_nomination_batch import DefaultNominationBatch
from helix_platform_api_public_client.models.default_nomination_declaration_type import DefaultNominationDeclarationType
from helix_platform_api_public_client.models.default_nomination_details import DefaultNominationDetails
from helix_platform_api_public_client.models.default_nomination_mtu import DefaultNominationMtu
from helix_platform_api_public_client.models.default_nomination_options import DefaultNominationOptions
from helix_platform_api_public_client.models.default_nomination_sort_by import DefaultNominationSortBy
from helix_platform_api_public_client.models.default_nomination_status import DefaultNominationStatus
from helix_platform_api_public_client.models.error_code import ErrorCode
from helix_platform_api_public_client.models.error_response import ErrorResponse
from helix_platform_api_public_client.models.interface import Interface
from helix_platform_api_public_client.models.intra_day_nomination_gate import IntraDayNominationGate
from helix_platform_api_public_client.models.intra_day_product_type import IntraDayProductType
from helix_platform_api_public_client.models.invite_organisation_user_request import InviteOrganisationUserRequest
from helix_platform_api_public_client.models.invited_organisation_user import InvitedOrganisationUser
from helix_platform_api_public_client.models.local_mtu_period import LocalMtuPeriod
from helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate import LongTermOrDayAheadNominationGate
from helix_platform_api_public_client.models.manual_file_upload_request import ManualFileUploadRequest
from helix_platform_api_public_client.models.message import Message
from helix_platform_api_public_client.models.message_batch import MessageBatch
from helix_platform_api_public_client.models.message_category import MessageCategory
from helix_platform_api_public_client.models.message_sender import MessageSender
from helix_platform_api_public_client.models.message_severity import MessageSeverity
from helix_platform_api_public_client.models.message_sort_by import MessageSortBy
from helix_platform_api_public_client.models.message_type import MessageType
from helix_platform_api_public_client.models.mtu_period import MtuPeriod
from helix_platform_api_public_client.models.mtu_size import MtuSize
from helix_platform_api_public_client.models.mtu_size_per_timescale import MtuSizePerTimescale
from helix_platform_api_public_client.models.nested_error import NestedError
from helix_platform_api_public_client.models.nomination_capacity_resolution import NominationCapacityResolution
from helix_platform_api_public_client.models.nomination_gate_status import NominationGateStatus
from helix_platform_api_public_client.models.nomination_gates_overview_response import NominationGatesOverviewResponse
from helix_platform_api_public_client.models.nomination_gates_overview_response_day_ahead import NominationGatesOverviewResponseDayAhead
from helix_platform_api_public_client.models.nomination_gates_overview_response_intra_day import NominationGatesOverviewResponseIntraDay
from helix_platform_api_public_client.models.nomination_gates_overview_response_long_term import NominationGatesOverviewResponseLongTerm
from helix_platform_api_public_client.models.notification_preference import NotificationPreference
from helix_platform_api_public_client.models.notification_preference_with_sms import NotificationPreferenceWithSms
from helix_platform_api_public_client.models.organisation import Organisation
from helix_platform_api_public_client.models.organisation_auth_method import OrganisationAuthMethod
from helix_platform_api_public_client.models.organisation_contact import OrganisationContact
from helix_platform_api_public_client.models.organisation_contact_information import OrganisationContactInformation
from helix_platform_api_public_client.models.organisation_file_settings import OrganisationFileSettings
from helix_platform_api_public_client.models.organisation_market_settings import OrganisationMarketSettings
from helix_platform_api_public_client.models.organisation_market_settings_fr_nomination_settings import OrganisationMarketSettingsFrNominationSettings
from helix_platform_api_public_client.models.organisation_market_settings_gb_nomination_settings import OrganisationMarketSettingsGbNominationSettings
from helix_platform_api_public_client.models.organisation_status import OrganisationStatus
from helix_platform_api_public_client.models.organisation_type import OrganisationType
from helix_platform_api_public_client.models.organisation_user import OrganisationUser
from helix_platform_api_public_client.models.organisation_user_batch import OrganisationUserBatch
from helix_platform_api_public_client.models.organisation_user_sort_by import OrganisationUserSortBy
from helix_platform_api_public_client.models.participant import Participant
from helix_platform_api_public_client.models.participant_dashboard_default_nominations_data import ParticipantDashboardDefaultNominationsData
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data import ParticipantDashboardInterconnectorCapacityData
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus import ParticipantDashboardInterconnectorCapacityDataMtus
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus_values import ParticipantDashboardInterconnectorCapacityDataMtusValues
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus_values_data import ParticipantDashboardInterconnectorCapacityDataMtusValuesData
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data import ParticipantDashboardInterconnectorCapacityGraphData
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus import ParticipantDashboardInterconnectorCapacityGraphDataMtus
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_netted_nominations import ParticipantDashboardInterconnectorCapacityGraphDataMtusNettedNominations
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_values import ParticipantDashboardInterconnectorCapacityGraphDataMtusValues
from helix_platform_api_public_client.models.participant_dashboard_messages import ParticipantDashboardMessages
from helix_platform_api_public_client.models.participant_dashboard_netted_nominations_data import ParticipantDashboardNettedNominationsData
from helix_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus import ParticipantDashboardNettedNominationsDataMtus
from helix_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_aggregated_nominations import ParticipantDashboardNettedNominationsDataMtusAggregatedNominations
from helix_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_netted_nominations import ParticipantDashboardNettedNominationsDataMtusNettedNominations
from helix_platform_api_public_client.models.participant_dashboard_next_nomination_gates import ParticipantDashboardNextNominationGates
from helix_platform_api_public_client.models.participant_dashboard_nomination_options import ParticipantDashboardNominationOptions
from helix_platform_api_public_client.models.participant_dashboard_nomination_options_timescale import ParticipantDashboardNominationOptionsTimescale
from helix_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data import ParticipantDashboardTransmissionRightsAndNominationsData
from helix_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus import ParticipantDashboardTransmissionRightsAndNominationsDataMtus
from helix_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus_values import ParticipantDashboardTransmissionRightsAndNominationsDataMtusValues
from helix_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data import ParticipantDashboardTransmissionRightsAndNominationsGraphData
from helix_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus import ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtus
from helix_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus_values import ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtusValues
from helix_platform_api_public_client.models.participant_organisation_details import ParticipantOrganisationDetails
from helix_platform_api_public_client.models.participant_overview_data import ParticipantOverviewData
from helix_platform_api_public_client.models.participant_overview_data_contact_information import ParticipantOverviewDataContactInformation
from helix_platform_api_public_client.models.participant_overview_data_organisation_members import ParticipantOverviewDataOrganisationMembers
from helix_platform_api_public_client.models.permission import Permission
from helix_platform_api_public_client.models.platform_appearance import PlatformAppearance
from helix_platform_api_public_client.models.profile import Profile
from helix_platform_api_public_client.models.profile_details import ProfileDetails
from helix_platform_api_public_client.models.profile_user import ProfileUser
from helix_platform_api_public_client.models.profile_user_organisation import ProfileUserOrganisation
from helix_platform_api_public_client.models.public_platform_overview_response import PublicPlatformOverviewResponse
from helix_platform_api_public_client.models.public_platform_overview_response_mtus import PublicPlatformOverviewResponseMtus
from helix_platform_api_public_client.models.public_platform_overview_response_mtus_values import PublicPlatformOverviewResponseMtusValues
from helix_platform_api_public_client.models.submit_nominations_mtu import SubmitNominationsMtu
from helix_platform_api_public_client.models.submit_timescale_nominations_request import SubmitTimescaleNominationsRequest
from helix_platform_api_public_client.models.system_message_category import SystemMessageCategory
from helix_platform_api_public_client.models.timescale import Timescale
from helix_platform_api_public_client.models.timescale_long_term_or_day_ahead import TimescaleLongTermOrDayAhead
from helix_platform_api_public_client.models.timescale_nomination_mtu_status import TimescaleNominationMtuStatus
from helix_platform_api_public_client.models.timescale_nomination_options import TimescaleNominationOptions
from helix_platform_api_public_client.models.timescale_nomination_options_window_timing import TimescaleNominationOptionsWindowTiming
from helix_platform_api_public_client.models.timescale_nomination_status import TimescaleNominationStatus
from helix_platform_api_public_client.models.timescale_nomination_type import TimescaleNominationType
from helix_platform_api_public_client.models.timescale_nomination_window_status import TimescaleNominationWindowStatus
from helix_platform_api_public_client.models.timescale_nominations import TimescaleNominations
from helix_platform_api_public_client.models.timescale_nominations_mtus import TimescaleNominationsMtus
from helix_platform_api_public_client.models.timescale_nominations_mtus_current_nomination import TimescaleNominationsMtusCurrentNomination
from helix_platform_api_public_client.models.transmission_rights_overview import TransmissionRightsOverview
from helix_platform_api_public_client.models.transmission_rights_overview_mtus import TransmissionRightsOverviewMtus
from helix_platform_api_public_client.models.transmission_rights_overview_mtus_values import TransmissionRightsOverviewMtusValues
from helix_platform_api_public_client.models.transmission_rights_overview_mtus_values_timescales import TransmissionRightsOverviewMtusValuesTimescales
from helix_platform_api_public_client.models.unread_messages_response import UnreadMessagesResponse
from helix_platform_api_public_client.models.update_default_nomination_request import UpdateDefaultNominationRequest
from helix_platform_api_public_client.models.update_profile_details_request import UpdateProfileDetailsRequest
from helix_platform_api_public_client.models.update_user_request import UpdateUserRequest
from helix_platform_api_public_client.models.user import User
from helix_platform_api_public_client.models.user_organisation import UserOrganisation
from helix_platform_api_public_client.models.user_preferences import UserPreferences
from helix_platform_api_public_client.models.user_preferences_general_notifications import UserPreferencesGeneralNotifications
from helix_platform_api_public_client.models.user_role import UserRole
from helix_platform_api_public_client.models.user_status import UserStatus
from helix_platform_api_public_client.models.version import Version
from helix_platform_api_public_client.models.zendesk_chat_token_response import ZendeskChatTokenResponse



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class NominationGateStatus(str, Enum):
    """
    NominationGateStatus
    """

    """
    allowed enum values
    """
    OPEN = 'OPEN'
    CLOSED = 'CLOSED'
    NOT_YET_OPEN = 'NOT_YET_OPEN'
    CANCELLED = 'CANCELLED'

    @classmethod
    def from_json(cls, json_str: str) -> NominationGateStatus:
        """Create an instance of NominationGateStatus from a JSON string"""
        return NominationGateStatus(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.117
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class BusinessProcessStepLogicType(str, Enum):
    """
    BusinessProcessStepLogicType
    """

    """
    allowed enum values
    """
    INTERNAL_LOGIC = 'INTERNAL_LOGIC'
    REQUEST_GENERATION = 'REQUEST_GENERATION'
    REQUEST_SENDING = 'REQUEST_SENDING'
    RESPONSE_POLLING = 'RESPONSE_POLLING'
    RESPONSE_PROCESSING = 'RESPONSE_PROCESSING'
    REQUEST_PROCESSING = 'REQUEST_PROCESSING'
    RESPONSE_SENDING = 'RESPONSE_SENDING'

    @classmethod
    def from_json(cls, json_str: str) -> BusinessProcessStepLogicType:
        """Create an instance of BusinessProcessStepLogicType from a JSON string"""
        return BusinessProcessStepLogicType(json.loads(json_str))


